OC.L10N.register(
    "news",
    {
    "Saved" : "Gespäichert",
    "Download" : "Download",
    "Close" : "Zoumaachen",
    "filter" : "Filter",
    "Language" : "Sprooch",
    "Subscribe" : "Umellen",
    "No articles available" : "Keng Artikelen verfügbar",
    "Open website" : "Oppe Websäit",
    "by" : "vun",
    "from" : "vun",
    "Play audio" : "Toun ofspillen",
    "Download audio" : "Toun eroflueden",
    "Download video" : "Video eroflueden",
    "Description" : "Beschreiwung",
    "right" : "riets",
    "Jump to next article" : "Op den nächsten Artikel sprangen",
    "left" : "lénks",
    "Jump to previous article" : "Op den Artikel vu virdru sprangen",
    "Open article in new tab" : "Den Artikel an engem neien Tab opmaachen",
    "Refresh" : "Opfrëschen",
    "Load next folder" : "Den nächsten Dossier lueden",
    "Load previous folder" : "Den Dossier vu virdrun lueden",
    "Web address" : "Link",
    "Folder" : "Dossier",
    "No folder" : "Keen Dossier",
    "New folder" : "Neien Dossier",
    "Folder name" : "Dossiers Numm:",
    "Go back" : "Zeréckgoen",
    "Folder exists already!" : "Dësen Dossier gëtt et schonns!",
    "Credentials" : "Credentials",
    "Username" : "Benotzernumm",
    "Password" : "Passwuert",
    "New Folder" : "Neien Dossier",
    "Create" : "Erstellen",
    "Explore" : "Erfuerschen",
    "Rename" : "Ëm-benennen",
    "Menu" : "Menü",
    "Delete" : "Läschen",
    "Dismiss" : "Verworf",
    "Collapse" : "Zesumme falen",
    "Deleted folder" : "Dossier läschen",
    "Undo delete folder" : "Dossier läschen réckgängeg maachen",
    "Unread articles" : "Ongeliesen Artikelen",
    "All articles" : "All Artikelen",
    "Settings" : "Astellungen",
    "Show all articles" : "All d'Artikelen uweisen",
    "Subscriptions (OPML)" : "Abonnementer (OPML)",
    "Import" : "Import",
    "Export" : "Export",
    "Help" : "Hëllef",
    "Documentation" : "Dokumentatioun",
    "Report a bug" : "E Feeler melden"
},
"nplurals=2; plural=(n != 1);");
